==> webpdf-wsclient-1.0.1-sources.jar: net/webpdf/wsclient/schema/operation/ExtractionWordsType.java <==

package net.webpdf.wsclient.schema.operation;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for ExtractionWordsType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="ExtractionWordsType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;extension base="{http://schema.webpdf.de/1.0/operation}BaseExtractionType"&gt;
 *       &lt;attribute name="removePunctuation" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *       &lt;attribute name="delimitAfterPunctuation" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" /&gt;
 *       &lt;attribute name="extendedSequenceCharacters" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" /&gt;
 *     &lt;/extension&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ExtractionWordsType")
public class ExtractionWordsType
    extends BaseExtractionType
{

    @XmlAttribute(name = "removePunctuation")
    protected Boolean removePunctuation;
    @XmlAttribute(name = "delimitAfterPunctuation")
    protected Boolean delimitAfterPunctuation;
    @XmlAttribute(name = "extendedSequenceCharacters")
    protected Boolean extendedSequenceCharacters;

    /**
     * Gets the value of the removePunctuation property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isRemovePunctuation() {
        if (removePunctuation == null) {
            return false;
        } else {
            return removePunctuation;
        }
    }

    /**
     * Sets the value of the removePunctuation property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setRemovePunctuation(boolean value) {
        this.removePunctuation = value;
    }

    public boolean isSetRemovePunctuation() {
        return (this.removePunctuation!= null);
    }

    public void unsetRemovePunctuation() {
        this.removePunctuation = null;
    }

    /**
     * Gets the value of the delimitAfterPunctuation property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isDelimitAfterPunctuation() {
        if (delimitAfterPunctuation == null) {
            return true;
        } else {
            return delimitAfterPunctuation;
        }
    }

    /**
     * Sets the value of the delimitAfterPunctuation property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setDelimitAfterPunctuation(boolean value) {
        this.delimitAfterPunctuation = value;
    }

    public boolean isSetDelimitAfterPunctuation() {
        return (this.delimitAfterPunctuation!= null);
    }

    public void unsetDelimitAfterPunctuation() {
        this.delimitAfterPunctuation = null;
    }

    /**
     * Gets the value of the extendedSequenceCharacters property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isExtendedSequenceCharacters() {
        if (extendedSequenceCharacters == null) {
            return false;
        } else {
            return extendedSequenceCharacters;
        }
    }

    /**
     * Sets the value of the extendedSequenceCharacters property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setExtendedSequenceCharacters(boolean value) {
        this.extendedSequenceCharacters = value;
    }

    public boolean isSetExtendedSequenceCharacters() {
        return (this.extendedSequenceCharacters!= null);
    }

    public void unsetExtendedSequenceCharacters() {
        this.extendedSequenceCharacters = null;
    }

}

==> webpdf-wsclient-9.0.0-sources.jar: net/webpdf/wsclient/schema/operation/ExtractionWordsType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Extract all the words from the PDF document, with page and position information.&lt;/p&gt;
 * </pre>
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Generates an ASCII text, XML, or JSON file that will be returned as a result when the web service is called. For each found word, the file will contain the page number and the X-axis and Y-axis coordinates of the word. When the TEXT output format is selected, only the word's text will be output, separated with line breaks.&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for ExtractionWordsType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="ExtractionWordsType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}BaseExtractionType">
 *       <attribute name="removePunctuation" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *       <attribute name="delimitAfterPunctuation" type="{http://www.w3.org/2001/XMLSchema}boolean" default="true" />
 *       <attribute name="extendedSequenceCharacters" type="{http://www.w3.org/2001/XMLSchema}boolean" default="false" />
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ExtractionWordsType")
public class ExtractionWordsType
    extends BaseExtractionType
{

    @XmlAttribute(name = "removePunctuation")
    protected Boolean removePunctuation;
    @XmlAttribute(name = "delimitAfterPunctuation")
    protected Boolean delimitAfterPunctuation;
    @XmlAttribute(name = "extendedSequenceCharacters")
    protected Boolean extendedSequenceCharacters;

    /**
     * Gets the value of the removePunctuation property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isRemovePunctuation() {
        if (removePunctuation == null) {
            return false;
        } else {
            return removePunctuation;
        }
    }

    /**
     * Sets the value of the removePunctuation property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setRemovePunctuation(boolean value) {
        this.removePunctuation = value;
    }

    public boolean isSetRemovePunctuation() {
        return (this.removePunctuation!= null);
    }

    public void unsetRemovePunctuation() {
        this.removePunctuation = null;
    }

    /**
     * Gets the value of the delimitAfterPunctuation property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isDelimitAfterPunctuation() {
        if (delimitAfterPunctuation == null) {
            return true;
        } else {
            return delimitAfterPunctuation;
        }
    }

    /**
     * Sets the value of the delimitAfterPunctuation property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setDelimitAfterPunctuation(boolean value) {
        this.delimitAfterPunctuation = value;
    }

    public boolean isSetDelimitAfterPunctuation() {
        return (this.delimitAfterPunctuation!= null);
    }

    public void unsetDelimitAfterPunctuation() {
        this.delimitAfterPunctuation = null;
    }

    /**
     * Gets the value of the extendedSequenceCharacters property.
     * 
     * @return
     *     possible object is
     *     {@link Boolean }
     *     
     */
    public boolean isExtendedSequenceCharacters() {
        if (extendedSequenceCharacters == null) {
            return false;
        } else {
            return extendedSequenceCharacters;
        }
    }

    /**
     * Sets the value of the extendedSequenceCharacters property.
     * 
     * @param value
     *     allowed object is
     *     {@link Boolean }
     *     
     */
    public void setExtendedSequenceCharacters(boolean value) {
        this.extendedSequenceCharacters = value;
    }

    public boolean isSetExtendedSequenceCharacters() {
        return (this.extendedSequenceCharacters!= null);
    }

    public void unsetExtendedSequenceCharacters() {
        this.extendedSequenceCharacters = null;
    }

}
